package com.goldencode.testcases.dmo.p2j_test.impl;

import java.io.Serializable;
import java.util.*;
import com.goldencode.p2j.persist.*;
import com.goldencode.p2j.util.*;
import com.goldencode.testcases.dmo.p2j_test.*;

/**
 * Data Model Object corresponding with table <code>p2j_test.address</code>
 * (previously <code>p2j_test.address</code>).
 */
@LegacyTable(name = "address", table = "address")
@LegacyIndexes(
{
   @LegacyIndex(name = "addr-id", converted = "address_addr_id",  primary = true),
   @LegacyIndex(name = "city-state", converted = "address_city_state"),
   @LegacyIndex(name = "street", converted = "address_street"),
   @LegacyIndex(name = "zip", converted = "address_zip")
})
public class AddressImpl
implements Serializable,
           Persistable,
           Address
{
   /** Surrogate primary key */
   private Long id = null;

   /** Addr ID */
   @LegacyField( fieldId = 1 , name = "addr-id" , format = "999999" , initial = "0" , columnLabel = "Addr ID" , label = "Addr ID" , mandatory = true)
   private final integer addrId;

   /** Street */
   @LegacyField( fieldId = 2 , name = "street" , format = "x(35)" , columnLabel = "Street" , label = "Street")
   private final character street;

   /** City */
   @LegacyField( fieldId = 3 , name = "city" , format = "x(15)" , columnLabel = "City" , label = "City")
   private final character city;

   /** State */
   @LegacyField( fieldId = 4 , name = "state" , format = "x(2)" , columnLabel = "State" , label = "State")
   private final character state;

   /** Zip Code */
   @LegacyField( fieldId = 5 , name = "zip-code" , format = "x(7)" , columnLabel = "Zip Code" , label = "Zip Code")
   private final character zipCode;

   /** Addr Type */
   @LegacyField( fieldId = 6 , name = "addr-type" , format = "x(12)" , columnLabel = "Addr Type" , label = "Addr Type")
   private final character addrType;

   /**
    * Default constructor.
    */
   public AddressImpl()
   {
      addrId = new integer(0);
      street = new character("");
      city = new character("");
      state = new character("");
      zipCode = new character("");
      addrType = new character("");
   }

   /**
    * Make a deep copy of the current DMO instance and return it.
    * 
    * @return  A new instance of this class whose data is identical to that of
    *          this instance.
    */
   public Undoable deepCopy()
   {
      Undoable copy = new AddressImpl();
      copy.assign(this);
      return copy;
   }

   /**
    * Modify the contained data of the instance to copy the instance data from
    * the given, backup instance.
    * 
    * @param   old
    *          The backup instance from which to copy data.
    */
   public void assign(Undoable old)
   {
      AddressImpl from = (AddressImpl) old;
      setId(from.getId());
      setAddrId(from.getAddrId());
      setStreet(from.getStreet());
      setCity(from.getCity());
      setState(from.getState());
      setZipCode(from.getZipCode());
      setAddrType(from.getAddrType());
   }

   /**
    * Getter: Surrogate primary key
    * 
    * @return  Primary key
    */
   public Long getId()
   {
      return id;
   }

   /**
    * Setter: Surrogate primary key
    * 
    * @param   id
    *          Primary key
    */
   public void setId(Long id)
   {
      this.id = id;
   }

   /**
    * Getter: Addr ID
    * 
    * @return  Addr ID
    */
   public integer getAddrId()
   {
      return (new integer(addrId));
   }

   /**
    * Setter: Addr ID
    * 
    * @param   addrId
    *          Addr ID
    */
   public void setAddrId(NumberType addrId)
   {
      this.addrId.assign(addrId, true);
   }

   /**
    * Getter: Street
    * 
    * @return  Street
    */
   public character getStreet()
   {
      return (new character(street));
   }

   /**
    * Setter: Street
    * 
    * @param   street
    *          Street
    */
   public void setStreet(Text street)
   {
      this.street.assign(street, true);
   }

   /**
    * Getter: City
    * 
    * @return  City
    */
   public character getCity()
   {
      return (new character(city));
   }

   /**
    * Setter: City
    * 
    * @param   city
    *          City
    */
   public void setCity(Text city)
   {
      this.city.assign(city, true);
   }

   /**
    * Getter: State
    * 
    * @return  State
    */
   public character getState()
   {
      return (new character(state));
   }

   /**
    * Setter: State
    * 
    * @param   state
    *          State
    */
   public void setState(Text state)
   {
      this.state.assign(state, true);
   }

   /**
    * Getter: Zip Code
    * 
    * @return  Zip Code
    */
   public character getZipCode()
   {
      return (new character(zipCode));
   }

   /**
    * Setter: Zip Code
    * 
    * @param   zipCode
    *          Zip Code
    */
   public void setZipCode(Text zipCode)
   {
      this.zipCode.assign(zipCode, true);
   }

   /**
    * Getter: Addr Type
    * 
    * @return  Addr Type
    */
   public character getAddrType()
   {
      return (new character(addrType));
   }

   /**
    * Setter: Addr Type
    * 
    * @param   addrType
    *          Addr Type
    */
   public void setAddrType(Text addrType)
   {
      this.addrType.assign(addrType, true);
   }
}
