package com.goldencode.testcases.dmo.p2j_test.impl;

import java.io.Serializable;
import java.util.*;
import com.goldencode.p2j.persist.*;
import com.goldencode.p2j.util.*;
import com.goldencode.testcases.dmo.p2j_test.*;

/**
 * Data Model Object corresponding with table <code>p2j_test.`cust`</code>
 * (previously <code>p2j_test.cust</code>).
 */
@LegacyTable(name = "cust", table = "`cust`")
public class CustImpl
implements Serializable,
           Persistable,
           Cust
{
   /** Surrogate primary key */
   private Long id = null;

   /** conflicting name with other table's field */
   @LegacyField( fieldId = 1 , name = "p2j" , format = "->>,>>9.99" , initial = "0")
   private final decimal p2j;

   /**
    * Default constructor.
    */
   public CustImpl()
   {
      p2j = new decimal(0, 2);
   }

   /**
    * Make a deep copy of the current DMO instance and return it.
    * 
    * @return  A new instance of this class whose data is identical to that of
    *          this instance.
    */
   public Undoable deepCopy()
   {
      Undoable copy = new CustImpl();
      copy.assign(this);
      return copy;
   }

   /**
    * Modify the contained data of the instance to copy the instance data from
    * the given, backup instance.
    * 
    * @param   old
    *          The backup instance from which to copy data.
    */
   public void assign(Undoable old)
   {
      CustImpl from = (CustImpl) old;
      setId(from.getId());
      setP2j(from.getP2j());
   }

   /**
    * Getter: Surrogate primary key
    * 
    * @return  Primary key
    */
   public Long getId()
   {
      return id;
   }

   /**
    * Setter: Surrogate primary key
    * 
    * @param   id
    *          Primary key
    */
   public void setId(Long id)
   {
      this.id = id;
   }

   /**
    * Getter: conflicting name with other table's field
    * 
    * @return  p2j
    */
   public decimal getP2j()
   {
      return (new decimal(p2j));
   }

   /**
    * Setter: conflicting name with other table's field
    * 
    * @param   p2j
    *          p2j
    */
   public void setP2j(NumberType p2j)
   {
      this.p2j.assign(p2j, true);
   }
}
