package com.goldencode.testcases.dmo.p2j_test.impl;

import java.io.Serializable;
import java.util.*;
import com.goldencode.p2j.persist.*;
import com.goldencode.p2j.util.*;
import com.goldencode.testcases.dmo.p2j_test.*;

/**
 * Data Model Object corresponding with table
 * <code>p2j_test.`new_person`</code> (previously
 * <code>p2j_test.person</code>).
 * <p>
 * Test table with variety of indexes
 */
@LegacyTable(name = "person", table = "`new_person`")
@LegacyIndexes(
{
   @LegacyIndex(name = "site-emp", converted = "`new_person_site_emp`",  primary = true),
   @LegacyIndex(name = "comments", converted = "`new_person_comments`"),
   @LegacyIndex(name = "emp-ssn", converted = "`new_person_emp_ssn`"),
   @LegacyIndex(name = "exten", converted = "`new_person_exten`"),
   @LegacyIndex(name = "hire-date", converted = "`new_person_hire_date`"),
   @LegacyIndex(name = "name", converted = "`new_person_name`"),
   @LegacyIndex(name = "pay-type", converted = "`new_person_pay_type`"),
   @LegacyIndex(name = "phone", converted = "`new_person_phone`"),
   @LegacyIndex(name = "term-date", converted = "`new_person_term_date`")
})
public class NewPersonImpl
implements Serializable,
           Persistable,
           NewPerson
{
   /** Surrogate primary key */
   private Long id = null;

   /** Site ID */
   @LegacyField( fieldId = 1 , name = "site-id" , format = "99" , initial = "0" , columnLabel = "Site ID" , label = "Site ID" , mandatory = true)
   private final integer site_id;

   /** Data member */
   @LegacyField( fieldId = 2 , name = "emp-num" , format = "9999999" , initial = "0" , columnLabel = "Emp Num Column" , mandatory = true)
   private final integer empNum;

   /** First */
   @LegacyField( fieldId = 3 , name = "first-name" , format = "x(12)" , columnLabel = "First" , label = "First")
   private final character firstName;

   /** Last */
   @LegacyField( fieldId = 4 , name = "last-name" , format = "x(15)" , columnLabel = "Last" , label = "Last")
   private final character lastName;

   /** MI */
   @LegacyField( fieldId = 5 , name = "middle-init" , format = "X" , columnLabel = "MI" , label = "MI")
   private final character newMiddleInit;

   /** SSN */
   @LegacyField( fieldId = 6 , name = "ssn" , format = "x(9)" , initial = "?" , columnLabel = "SSN" , label = "SSN" , mandatory = true)
   private final character ssn;

   /** Pay Type */
   @LegacyField( fieldId = 7 , name = "pay-type" , format = "X" , columnLabel = "Pay Type" , label = "Pay Type")
   private final character payType;

   /** Hired */
   @LegacyField( fieldId = 8 , name = "hire-date" , format = "99/99/9999" , initial = "?" , columnLabel = "Hired" , label = "Hired")
   private final date hireDate;

   /** Terminated */
   @LegacyField( fieldId = 9 , name = "term-date" , format = "99/99/9999" , initial = "?" , columnLabel = "Terminated" , label = "Terminated")
   private final date termDate;

   /** Termination Notice TS */
   @LegacyField( fieldId = 10 , name = "term-notice" , format = "99/99/9999 HH:MM:SS.sss" , initial = "?" , columnLabel = "Termination Notice TS" , label = "Termination Notice TS")
   private final datetime termNotice;

   /** Termination Notice TS-Ext */
   @LegacyField( fieldId = 11 , name = "term-notice-ext" , format = "99/99/9999 HH:MM:SS.sss+HH:MM" , initial = "?" , columnLabel = "Termination Notice TS-Ext" , label = "Termination Notice TS-Ext")
   private final datetimetz termNoticeExt;

   /** Data member */
   @LegacyField( fieldId = 12 , name = "comments" , format = "x(60)")
   private final character comments;

   /** Area Code */
   @LegacyField( fieldId = 13 , name = "area-code" , format = "x(3)" , columnLabel = "Area Code" , label = "Area Code")
   private final character areaCode;

   /** Phone */
   @LegacyField( fieldId = 14 , name = "phone-number" , format = "x(7)" , columnLabel = "Phone" , label = "Phone")
   private final character phoneNumber;

   /** Ext */
   @LegacyField( fieldId = 15 , name = "extension" , format = "x(4)" , columnLabel = "Ext" , label = "Ext")
   private final character extension;

   /**
    * List of composite properties; 5 elements of type {@link
    * NewPersonImpl.Composite5 Composite5}
    */
   private List composite5 = new ArrayList(5);

   /**
    * Default constructor.
    */
   public NewPersonImpl()
   {
      site_id = new integer(0);
      empNum = new integer(0);
      firstName = new character("");
      lastName = new character("");
      newMiddleInit = new character("");
      ssn = new character();
      payType = new character("");
      hireDate = new date();
      termDate = new date();
      termNotice = new datetime();
      termNoticeExt = new datetimetz();
      comments = new character("");
      areaCode = new character("");
      phoneNumber = new character("");
      extension = new character("");
      
      // Populate Composite5 list.
      for (int i = 0; i < 5; i++)
      {
         composite5.add(new Composite5());
      }
   }

   /**
    * Make a deep copy of the current DMO instance and return it.
    * 
    * @return  A new instance of this class whose data is identical to that of
    *          this instance.
    */
   public Undoable deepCopy()
   {
      Undoable copy = new NewPersonImpl();
      copy.assign(this);
      return copy;
   }

   /**
    * Modify the contained data of the instance to copy the instance data from
    * the given, backup instance.
    * 
    * @param   old
    *          The backup instance from which to copy data.
    */
   public void assign(Undoable old)
   {
      NewPersonImpl from = (NewPersonImpl) old;
      setId(from.getId());
      setSite_id(from.getSite_id());
      setEmpNum(from.getEmpNum());
      setFirstName(from.getFirstName());
      setLastName(from.getLastName());
      setNewMiddleInit(from.getNewMiddleInit());
      setSsn(from.getSsn());
      setPayType(from.getPayType());
      setHireDate(from.getHireDate());
      setTermDate(from.getTermDate());
      setTermNotice(from.getTermNotice());
      setTermNoticeExt(from.getTermNoticeExt());
      setComments(from.getComments());
      setAreaCode(from.getAreaCode());
      setPhoneNumber(from.getPhoneNumber());
      setExtension(from.getExtension());
      
      // Assign Composite5 properties.
      for (int i = 0; i < 5; i++)
      {
         setSchedule_property(i, from.getSchedule_property(i));
         setHours(i, from.getHours(i));
      }
   }

   /**
    * Getter: Surrogate primary key
    * 
    * @return  Primary key
    */
   public Long getId()
   {
      return id;
   }

   /**
    * Setter: Surrogate primary key
    * 
    * @param   id
    *          Primary key
    */
   public void setId(Long id)
   {
      this.id = id;
   }

   /**
    * Getter: Site ID
    * 
    * @return  Site ID
    */
   public integer getSite_id()
   {
      return (new integer(site_id));
   }

   /**
    * Setter: Site ID
    * 
    * @param   site_id
    *          Site ID
    */
   public void setSite_id(NumberType site_id)
   {
      this.site_id.assign(site_id, true);
   }

   /**
    * Getter: empNum
    * 
    * @return  empNum
    */
   public integer getEmpNum()
   {
      return (new integer(empNum));
   }

   /**
    * Setter: empNum
    * 
    * @param   empNum
    *          empNum
    */
   public void setEmpNum(NumberType empNum)
   {
      this.empNum.assign(empNum, true);
   }

   /**
    * Getter: First
    * 
    * @return  First
    */
   public character getFirstName()
   {
      return (new character(firstName));
   }

   /**
    * Setter: First
    * 
    * @param   firstName
    *          First
    */
   public void setFirstName(Text firstName)
   {
      this.firstName.assign(firstName, true);
   }

   /**
    * Getter: Last
    * 
    * @return  Last
    */
   public character getLastName()
   {
      return (new character(lastName));
   }

   /**
    * Setter: Last
    * 
    * @param   lastName
    *          Last
    */
   public void setLastName(Text lastName)
   {
      this.lastName.assign(lastName, true);
   }

   /**
    * Getter: MI
    * 
    * @return  MI
    */
   public character getNewMiddleInit()
   {
      return (new character(newMiddleInit));
   }

   /**
    * Setter: MI
    * 
    * @param   newMiddleInit
    *          MI
    */
   public void setNewMiddleInit(Text newMiddleInit)
   {
      this.newMiddleInit.assign(newMiddleInit, true);
   }

   /**
    * Getter: SSN
    * 
    * @return  SSN
    */
   public character getSsn()
   {
      return (new character(ssn));
   }

   /**
    * Setter: SSN
    * 
    * @param   ssn
    *          SSN
    */
   public void setSsn(Text ssn)
   {
      this.ssn.assign(ssn, true);
   }

   /**
    * Getter: Pay Type
    * 
    * @return  Pay Type
    */
   public character getPayType()
   {
      return (new character(payType));
   }

   /**
    * Setter: Pay Type
    * 
    * @param   payType
    *          Pay Type
    */
   public void setPayType(Text payType)
   {
      this.payType.assign(payType, true);
   }

   /**
    * Getter: Hired
    * 
    * @return  Hired
    */
   public date getHireDate()
   {
      return (new date(hireDate));
   }

   /**
    * Setter: Hired
    * 
    * @param   hireDate
    *          Hired
    */
   public void setHireDate(date hireDate)
   {
      this.hireDate.assign(hireDate, true);
   }

   /**
    * Getter: Terminated
    * 
    * @return  Terminated
    */
   public date getTermDate()
   {
      return (new date(termDate));
   }

   /**
    * Setter: Terminated
    * 
    * @param   termDate
    *          Terminated
    */
   public void setTermDate(date termDate)
   {
      this.termDate.assign(termDate, true);
   }

   /**
    * Getter: Termination Notice TS
    * 
    * @return  Termination Notice TS
    */
   public datetime getTermNotice()
   {
      return (new datetime(termNotice));
   }

   /**
    * Setter: Termination Notice TS
    * 
    * @param   termNotice
    *          Termination Notice TS
    */
   public void setTermNotice(date termNotice)
   {
      this.termNotice.assign(termNotice, true);
   }

   /**
    * Getter: Termination Notice TS-Ext
    * 
    * @return  Termination Notice TS-Ext
    */
   public datetimetz getTermNoticeExt()
   {
      return (new datetimetz(termNoticeExt));
   }

   /**
    * Setter: Termination Notice TS-Ext
    * 
    * @param   termNoticeExt
    *          Termination Notice TS-Ext
    */
   public void setTermNoticeExt(date termNoticeExt)
   {
      this.termNoticeExt.assign(termNoticeExt, true);
   }

   /**
    * Getter: comments
    * 
    * @return  comments
    */
   public character getComments()
   {
      return (new character(comments));
   }

   /**
    * Setter: comments
    * 
    * @param   comments
    *          comments
    */
   public void setComments(Text comments)
   {
      this.comments.assign(comments, true);
   }

   /**
    * Getter: Area Code
    * 
    * @return  Area Code
    */
   public character getAreaCode()
   {
      return (new character(areaCode));
   }

   /**
    * Setter: Area Code
    * 
    * @param   areaCode
    *          Area Code
    */
   public void setAreaCode(Text areaCode)
   {
      this.areaCode.assign(areaCode, true);
   }

   /**
    * Getter: Phone
    * 
    * @return  Phone
    */
   public character getPhoneNumber()
   {
      return (new character(phoneNumber));
   }

   /**
    * Setter: Phone
    * 
    * @param   phoneNumber
    *          Phone
    */
   public void setPhoneNumber(Text phoneNumber)
   {
      this.phoneNumber.assign(phoneNumber, true);
   }

   /**
    * Getter: Ext
    * 
    * @return  Ext
    */
   public character getExtension()
   {
      return (new character(extension));
   }

   /**
    * Setter: Ext
    * 
    * @param   extension
    *          Ext
    */
   public void setExtension(Text extension)
   {
      this.extension.assign(extension, true);
   }

   /**
    * Indexed Getter: schedule_property
    * 
    * @param   index
    *          Index of element (where <code>0 &lt;= <em>index</em> &lt;
    *          5</code>).
    * 
    * @return  schedule_property
    */
   public character getSchedule_property(int index)
   {
      return ((Composite5) composite5.get(index)).getSchedule_property();
   }

   /**
    * Getter: schedule_property
    * 
    * @return  schedule_property
    */
   public character[] getSchedule_property()
   {
      character[] _schedule_property = new character[5];
      for (int i = 0; i < 5; i++)
      {
         _schedule_property[i] = getSchedule_property(i);
      }
      return _schedule_property;
   }

   /**
    * Indexed Getter: schedule_property
    * 
    * @param   index
    *          Index of element (where <code>0 &lt;= <em>index</em> &lt;
    *          5</code>).
    * 
    * @return  schedule_property
    */
   public character getSchedule_property(NumberType index)
   {
      return getSchedule_property(index.intValue());
   }

   /**
    * Indexed Setter: schedule_property
    * 
    * @param   index
    *          Index of element (where <code>0 &lt;= <em>index</em> &lt;
    *          5</code>).
    * @param   element
    *          schedule_property
    */
   public void setSchedule_property(int index, Text element)
   {
      ((Composite5) composite5.get(index)).setSchedule_property(element);
   }

   /**
    * Indexed Setter: schedule_property
    * 
    * @param   index
    *          Index of element (where <code>0 &lt;= <em>index</em> &lt;
    *          5</code>).
    * @param   element
    *          schedule_property
    */
   public void setSchedule_property(NumberType index, Text element)
   {
      setSchedule_property(index.intValue(), element);
   }

   /**
    * Set all elements of the target list property to the given scalar value.
    * Modifies the contents of: schedule_property
    * 
    * @param   element
    *          Scalar value to which to set all elements of: schedule_property
    */
   public void setSchedule_property(Text element)
   {
      int len = composite5.size();
      for (int i = 0; i < len; i++)
      {
         setSchedule_property(i, element);
      }
   }

   /**
    * Set as many elements of the target list property as are provided in the
    * given array of scalar values. Modifies the contents of:
    * schedule_property
    * <p>
    * If the given array is larger than the target list, any additional
    * elements in the given array are ignored. If the target array is smaller
    * than the target list, only those elements whose array indices match are
    * updated.
    * 
    * @param   elements
    *          Array of scalar values to which to set the corresponding
    *          elements of: schedule_property
    */
   public void setSchedule_property(Text[] elements)
   {
      int len = Math.min(elements.length, composite5.size());
      for (int i = 0; i < len; i++)
      {
         setSchedule_property(i, elements[i]);
      }
   }

   /**
    * Report number of list elements for schedule_property
    * 
    * @return  Number of list elements for schedule_property
    */
   public integer sizeSchedule_property()
   {
      return (new integer(composite5.size()));
   }

   /**
    * Indexed Getter: Hours
    * 
    * @param   index
    *          Index of element (where <code>0 &lt;= <em>index</em> &lt;
    *          5</code>).
    * 
    * @return  Hours
    */
   public integer getHours(int index)
   {
      return ((Composite5) composite5.get(index)).getHours();
   }

   /**
    * Getter: Hours
    * 
    * @return  Hours
    */
   public integer[] getHours()
   {
      integer[] _hours = new integer[5];
      for (int i = 0; i < 5; i++)
      {
         _hours[i] = getHours(i);
      }
      return _hours;
   }

   /**
    * Indexed Getter: Hours
    * 
    * @param   index
    *          Index of element (where <code>0 &lt;= <em>index</em> &lt;
    *          5</code>).
    * 
    * @return  Hours
    */
   public integer getHours(NumberType index)
   {
      return getHours(index.intValue());
   }

   /**
    * Indexed Setter: Hours
    * 
    * @param   index
    *          Index of element (where <code>0 &lt;= <em>index</em> &lt;
    *          5</code>).
    * @param   element
    *          Hours
    */
   public void setHours(int index, NumberType element)
   {
      ((Composite5) composite5.get(index)).setHours(element);
   }

   /**
    * Indexed Setter: Hours
    * 
    * @param   index
    *          Index of element (where <code>0 &lt;= <em>index</em> &lt;
    *          5</code>).
    * @param   element
    *          Hours
    */
   public void setHours(NumberType index, NumberType element)
   {
      setHours(index.intValue(), element);
   }

   /**
    * Set all elements of the target list property to the given scalar value.
    * Modifies the contents of: Hours
    * 
    * @param   element
    *          Scalar value to which to set all elements of: Hours
    */
   public void setHours(NumberType element)
   {
      int len = composite5.size();
      for (int i = 0; i < len; i++)
      {
         setHours(i, element);
      }
   }

   /**
    * Set as many elements of the target list property as are provided in the
    * given array of scalar values. Modifies the contents of: Hours
    * <p>
    * If the given array is larger than the target list, any additional
    * elements in the given array are ignored. If the target array is smaller
    * than the target list, only those elements whose array indices match are
    * updated.
    * 
    * @param   elements
    *          Array of scalar values to which to set the corresponding
    *          elements of: Hours
    */
   public void setHours(NumberType[] elements)
   {
      int len = Math.min(elements.length, composite5.size());
      for (int i = 0; i < len; i++)
      {
         setHours(i, elements[i]);
      }
   }

   /**
    * Report number of list elements for Hours
    * 
    * @return  Number of list elements for Hours
    */
   public integer sizeHours()
   {
      return (new integer(composite5.size()));
   }

   /**
    * Inner class which composites properties of like extent. All properties
    * migrated from the legacy table <code>p2j_test.person</code> of extent 5
    * are data members of this class.
    */
   static class Composite5
   implements Serializable
   {
      /** Data member */
      @LegacyField( fieldId = 16 , name = "schedule" , format = "x(64)")
      private final character schedule_property;

      /** Hours */
      @LegacyField( fieldId = 17 , name = "hours" , format = "99" , initial = "0" , label = "Hours")
      private final integer hours;

      /**
       * Default constructor.
       */
      public Composite5()
      {
         schedule_property = new character("");
         hours = new integer(0);
      }

      /**
       * Getter: schedule_property
       * 
       * @return  schedule_property
       */
      public character getSchedule_property()
      {
         return (new character(schedule_property));
      }

      /**
       * Setter: schedule_property
       * 
       * @param   schedule_property
       *          schedule_property
       */
      public void setSchedule_property(Text schedule_property)
      {
         this.schedule_property.assign(schedule_property, true);
      }

      /**
       * Getter: Hours
       * 
       * @return  Hours
       */
      public integer getHours()
      {
         return (new integer(hours));
      }

      /**
       * Setter: Hours
       * 
       * @param   hours
       *          Hours
       */
      public void setHours(NumberType hours)
      {
         this.hours.assign(hours, true);
      }
   }
}
