package com.goldencode.testcases.dmo.p2j_test.impl;

import java.io.Serializable;
import java.util.*;
import com.goldencode.p2j.persist.*;
import com.goldencode.p2j.util.*;
import com.goldencode.testcases.dmo.p2j_test.*;

/**
 * Data Model Object corresponding with table <code>p2j_test.`p2j_test`</code>
 * (previously <code>p2j_test.p2j_test</code>).
 * <p>
 * This is an example of a table name that conflicts with the database name.
 */
@LegacyTable(name = "p2j_test", table = "`p2j_test`")
public class P2jTestImpl
implements Serializable,
           Persistable,
           P2jTest
{
   /** Surrogate primary key */
   private Long id = null;

   /** Field name that conflicts with a table name. */
   @LegacyField( fieldId = 1 , name = "customer" , format = "x(8)")
   private final character customer;

   /** Field name that conflicts with other field names (in different tables) */
   @LegacyField( fieldId = 2 , name = "description" , format = "x(8)")
   private final character description;

   /** Field name that is unique across the database. */
   @LegacyField( fieldId = 3 , name = "unique1" , format = "->,>>>,>>9" , initial = "0")
   private final integer unique1;

   /** conflicting name with cust table's field */
   @LegacyField( fieldId = 4 , name = "p2j" , format = "99/99/99" , initial = "?")
   private final date p2j;

   /**
    * Default constructor.
    */
   public P2jTestImpl()
   {
      customer = new character("");
      description = new character("");
      unique1 = new integer(0);
      p2j = new date();
   }

   /**
    * Make a deep copy of the current DMO instance and return it.
    * 
    * @return  A new instance of this class whose data is identical to that of
    *          this instance.
    */
   public Undoable deepCopy()
   {
      Undoable copy = new P2jTestImpl();
      copy.assign(this);
      return copy;
   }

   /**
    * Modify the contained data of the instance to copy the instance data from
    * the given, backup instance.
    * 
    * @param   old
    *          The backup instance from which to copy data.
    */
   public void assign(Undoable old)
   {
      P2jTestImpl from = (P2jTestImpl) old;
      setId(from.getId());
      setCustomer(from.getCustomer());
      setDescription(from.getDescription());
      setUnique1(from.getUnique1());
      setP2j(from.getP2j());
   }

   /**
    * Getter: Surrogate primary key
    * 
    * @return  Primary key
    */
   public Long getId()
   {
      return id;
   }

   /**
    * Setter: Surrogate primary key
    * 
    * @param   id
    *          Primary key
    */
   public void setId(Long id)
   {
      this.id = id;
   }

   /**
    * Getter: Field name that conflicts with a table name.
    * 
    * @return  customer
    */
   public character getCustomer()
   {
      return (new character(customer));
   }

   /**
    * Setter: Field name that conflicts with a table name.
    * 
    * @param   customer
    *          customer
    */
   public void setCustomer(Text customer)
   {
      this.customer.assign(customer, true);
   }

   /**
    * Getter: Field name that conflicts with other field names (in different
    * tables)
    * 
    * @return  description
    */
   public character getDescription()
   {
      return (new character(description));
   }

   /**
    * Setter: Field name that conflicts with other field names (in different
    * tables)
    * 
    * @param   description
    *          description
    */
   public void setDescription(Text description)
   {
      this.description.assign(description, true);
   }

   /**
    * Getter: Field name that is unique across the database.
    * 
    * @return  unique1
    */
   public integer getUnique1()
   {
      return (new integer(unique1));
   }

   /**
    * Setter: Field name that is unique across the database.
    * 
    * @param   unique1
    *          unique1
    */
   public void setUnique1(NumberType unique1)
   {
      this.unique1.assign(unique1, true);
   }

   /**
    * Getter: conflicting name with cust table's field
    * 
    * @return  p2j
    */
   public date getP2j()
   {
      return (new date(p2j));
   }

   /**
    * Setter: conflicting name with cust table's field
    * 
    * @param   p2j
    *          p2j
    */
   public void setP2j(date p2j)
   {
      this.p2j.assign(p2j, true);
   }
}
