package com.goldencode.testcases.dmo.p2j_test.impl;

import java.io.Serializable;
import java.util.*;
import com.goldencode.p2j.persist.*;
import com.goldencode.p2j.util.*;
import com.goldencode.testcases.dmo.p2j_test.*;

/**
 * Data Model Object corresponding with table
 * <code>p2j_test.`pers_addr`</code> (previously
 * <code>p2j_test.pers-addr</code>).
 */
@LegacyTable(name = "pers-addr", table = "`pers_addr`")
@LegacyIndexes(
{
   @LegacyIndex(name = "person", converted = "`pers_addr_person`",  primary = true),
   @LegacyIndex(name = "active", converted = "`pers_addr_active`"),
   @LegacyIndex(name = "address", converted = "`pers_addr_address`"),
   @LegacyIndex(name = "link-type", converted = "`pers_addr_link_type`")
})
public class PersAddrImpl
implements Serializable,
           Persistable,
           PersAddr
{
   /** Surrogate primary key */
   private Long id = null;

   /** Site ID */
   @LegacyField( fieldId = 1 , name = "site-id" , format = "99" , initial = "0" , columnLabel = "Site ID" , label = "Site ID" , mandatory = true)
   private final integer siteId;

   /** Emp Num */
   @LegacyField( fieldId = 2 , name = "emp-num" , format = "9999999" , initial = "0" , columnLabel = "Emp Num" , label = "Emp Num" , mandatory = true)
   private final integer empNum;

   /** Addr ID */
   @LegacyField( fieldId = 3 , name = "addr-id" , format = "999999" , initial = "0" , columnLabel = "Addr ID" , label = "Addr ID" , mandatory = true)
   private final integer addrId;

   /** Link Type */
   @LegacyField( fieldId = 4 , name = "link-type" , format = "x(12)" , columnLabel = "Link Type" , label = "Link Type")
   private final character linkType;

   /** Active */
   @LegacyField( fieldId = 5 , name = "active" , format = "yes/no" , initial = "false" , columnLabel = "Active" , label = "Active")
   private final logical active;

   /**
    * Default constructor.
    */
   public PersAddrImpl()
   {
      siteId = new integer(0);
      empNum = new integer(0);
      addrId = new integer(0);
      linkType = new character("");
      active = new logical(false);
   }

   /**
    * Make a deep copy of the current DMO instance and return it.
    * 
    * @return  A new instance of this class whose data is identical to that of
    *          this instance.
    */
   public Undoable deepCopy()
   {
      Undoable copy = new PersAddrImpl();
      copy.assign(this);
      return copy;
   }

   /**
    * Modify the contained data of the instance to copy the instance data from
    * the given, backup instance.
    * 
    * @param   old
    *          The backup instance from which to copy data.
    */
   public void assign(Undoable old)
   {
      PersAddrImpl from = (PersAddrImpl) old;
      setId(from.getId());
      setSiteId(from.getSiteId());
      setEmpNum(from.getEmpNum());
      setAddrId(from.getAddrId());
      setLinkType(from.getLinkType());
      setActive(from.isActive());
   }

   /**
    * Getter: Surrogate primary key
    * 
    * @return  Primary key
    */
   public Long getId()
   {
      return id;
   }

   /**
    * Setter: Surrogate primary key
    * 
    * @param   id
    *          Primary key
    */
   public void setId(Long id)
   {
      this.id = id;
   }

   /**
    * Getter: Site ID
    * 
    * @return  Site ID
    */
   public integer getSiteId()
   {
      return (new integer(siteId));
   }

   /**
    * Setter: Site ID
    * 
    * @param   siteId
    *          Site ID
    */
   public void setSiteId(NumberType siteId)
   {
      this.siteId.assign(siteId, true);
   }

   /**
    * Getter: Emp Num
    * 
    * @return  Emp Num
    */
   public integer getEmpNum()
   {
      return (new integer(empNum));
   }

   /**
    * Setter: Emp Num
    * 
    * @param   empNum
    *          Emp Num
    */
   public void setEmpNum(NumberType empNum)
   {
      this.empNum.assign(empNum, true);
   }

   /**
    * Getter: Addr ID
    * 
    * @return  Addr ID
    */
   public integer getAddrId()
   {
      return (new integer(addrId));
   }

   /**
    * Setter: Addr ID
    * 
    * @param   addrId
    *          Addr ID
    */
   public void setAddrId(NumberType addrId)
   {
      this.addrId.assign(addrId, true);
   }

   /**
    * Getter: Link Type
    * 
    * @return  Link Type
    */
   public character getLinkType()
   {
      return (new character(linkType));
   }

   /**
    * Setter: Link Type
    * 
    * @param   linkType
    *          Link Type
    */
   public void setLinkType(Text linkType)
   {
      this.linkType.assign(linkType, true);
   }

   /**
    * Getter: Active
    * 
    * @return  Active
    */
   public logical isActive()
   {
      return (new logical(active));
   }

   /**
    * Setter: Active
    * 
    * @param   active
    *          Active
    */
   public void setActive(logical active)
   {
      this.active.assign(active, true);
   }
}
