package com.goldencode.testcases.dmo.p2j_test.impl;

import java.io.Serializable;
import java.util.*;
import com.goldencode.p2j.persist.*;
import com.goldencode.p2j.util.*;
import com.goldencode.testcases.dmo.p2j_test.*;

/**
 * Data Model Object corresponding with table
 * <code>p2j_test.`vehicle_owner`</code> (previously
 * <code>p2j_test.vehicle-owner</code>).
 */
@LegacyTable(name = "vehicle-owner", table = "`vehicle_owner`")
@LegacyIndexes(
{
   @LegacyIndex(name = "pi-name", converted = "`vehicle_owner_pi_name`",  primary = true),
   @LegacyIndex(name = "si-vin", converted = "`vehicle_owner_si_vin`")
})
public class VehicleOwnerImpl
implements Serializable,
           Persistable,
           VehicleOwner
{
   /** Surrogate primary key */
   private Long id = null;

   /** Name; Owner name */
   @LegacyField( fieldId = 1 , name = "name" , format = "x(24)" , label = "Name" , mandatory = true)
   private final character name;

   /** VIN; Vehicle Identification Number */
   @LegacyField( fieldId = 2 , name = "vin-number" , format = "xxxx-xxxx-xxxx" , label = "VIN" , mandatory = true)
   private final character vinNumber;

   /** Price; Price paid for vehicle */
   @LegacyField( fieldId = 3 , name = "price" , format = "->>,>>9.99" , initial = "0" , label = "Price")
   private final decimal price;

   /**
    * Default constructor.
    */
   public VehicleOwnerImpl()
   {
      name = new character("");
      vinNumber = new character("");
      price = new decimal(0, 2);
   }

   /**
    * Make a deep copy of the current DMO instance and return it.
    * 
    * @return  A new instance of this class whose data is identical to that of
    *          this instance.
    */
   public Undoable deepCopy()
   {
      Undoable copy = new VehicleOwnerImpl();
      copy.assign(this);
      return copy;
   }

   /**
    * Modify the contained data of the instance to copy the instance data from
    * the given, backup instance.
    * 
    * @param   old
    *          The backup instance from which to copy data.
    */
   public void assign(Undoable old)
   {
      VehicleOwnerImpl from = (VehicleOwnerImpl) old;
      setId(from.getId());
      setName(from.getName());
      setVinNumber(from.getVinNumber());
      setPrice(from.getPrice());
   }

   /**
    * Getter: Surrogate primary key
    * 
    * @return  Primary key
    */
   public Long getId()
   {
      return id;
   }

   /**
    * Setter: Surrogate primary key
    * 
    * @param   id
    *          Primary key
    */
   public void setId(Long id)
   {
      this.id = id;
   }

   /**
    * Getter: Owner name
    * 
    * @return  Name
    */
   public character getName()
   {
      return (new character(name));
   }

   /**
    * Setter: Owner name
    * 
    * @param   name
    *          Name
    */
   public void setName(Text name)
   {
      this.name.assign(name, true);
   }

   /**
    * Getter: Vehicle Identification Number
    * 
    * @return  VIN
    */
   public character getVinNumber()
   {
      return (new character(vinNumber));
   }

   /**
    * Setter: Vehicle Identification Number
    * 
    * @param   vinNumber
    *          VIN
    */
   public void setVinNumber(Text vinNumber)
   {
      this.vinNumber.assign(vinNumber, true);
   }

   /**
    * Getter: Price paid for vehicle
    * 
    * @return  Price
    */
   public decimal getPrice()
   {
      return (new decimal(price));
   }

   /**
    * Setter: Price paid for vehicle
    * 
    * @param   price
    *          Price
    */
   public void setPrice(NumberType price)
   {
      this.price.assign(price, true);
   }
}
